sciduck documentation — sciduck documentation

# sciduck documentation

Add your content using `reStructuredText` syntax. See the reStructuredText documentation for details.

Contents:

- sciduck.basic_qc module
  - `filter_on_counts_genes()`
  - `filter_on_precomputed_metrics()`
  - `filter_utilizing_coarse_labels()`
- sciduck.entropy_qc module
  - `cell_entropy_qc_metric()`
  - `cluster_entropy_qc_metric()`
  - `filter_on_cluster_entropy()`
- sciduck.annotation_table module
  - `add_dominant_library_info()`
  - `build_annotation_table()`